@@ -14,19 +14,19 @@
     <message>
         <location filename="../mainwindow.ui" line="57"/>
         <source>Popular Applications</source>
-        <translation type="unfinished"></translation>
+        <translation>יישומים מועדפים</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="83"/>
         <location filename="../mainwindow.cpp" line="96"/>
         <source>Package</source>
-        <translation type="unfinished"></translation>
+        <translation>חבילה</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="88"/>
         <location filename="../mainwindow.cpp" line="96"/>
         <source>Info</source>
-        <translation type="unfinished"></translation>
+        <translation>מידע</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="93"/>
@@ -35,7 +35,7 @@
         <location filename="../mainwindow.ui" line="975"/>
         <location filename="../mainwindow.cpp" line="96"/>
         <source>Description</source>
-        <translation type="unfinished"></translation>
+        <translation>תיאור</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="113"/>
@@ -44,7 +44,7 @@
         <location filename="../mainwindow.ui" line="944"/>
         <location filename="../mainwindow.ui" line="1208"/>
         <source>search</source>
-        <translation type="unfinished"></translation>
+        <translation>חיפוש</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="123"/>
@@ -54,7 +54,7 @@
     <message>
         <location filename="../mainwindow.ui" line="153"/>
         <source>Stable Repo</source>
-        <translation type="unfinished"></translation>
+        <translation>מאגר יציב</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="174"/>
@@ -176,7 +176,7 @@
     <message>
         <location filename="../mainwindow.ui" line="493"/>
         <source>MX Test Repo</source>
-        <translation type="unfinished"></translation>
+        <translation>מאגר MX נסיוני</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="813"/>
@@ -301,12 +301,12 @@
     <message>
         <location filename="../mainwindow.ui" line="1560"/>
         <source>About this application</source>
-        <translation type="unfinished"></translation>
+        <translation>מידע לגבי התוכנה הזו</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1563"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation>אודות...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1570"/>
@@ -321,7 +321,7 @@
     <message>
         <location filename="../mainwindow.ui" line="1621"/>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>עזרה</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1628"/>
@@ -344,7 +344,7 @@
     <message>
         <location filename="../mainwindow.ui" line="1670"/>
         <source>Quit application</source>
-        <translation type="unfinished"></translation>
+        <translation>יציאה מהתוכנה</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1673"/>
@@ -382,10 +382,10 @@
         <location filename="../mainwindow.cpp" line="1959"/>
         <location filename="../mainwindow.cpp" line="1979"/>
         <location filename="../mainwindow.cpp" line="2382"/>
-        <location filename="../mainwindow.cpp" line="2456"/>
-        <location filename="../mainwindow.cpp" line="2483"/>
+        <location filename="../mainwindow.cpp" line="2457"/>
+        <location filename="../mainwindow.cpp" line="2484"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>תקלה</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="183"/>
@@ -396,12 +396,12 @@
         <location filename="../mainwindow.cpp" line="544"/>
         <location filename="../mainwindow.cpp" line="1813"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>ביטול</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="550"/>
         <source>Please wait...</source>
-        <translation type="unfinished"></translation>
+        <translation>חכה בבקשה...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="751"/>
@@ -454,7 +454,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="905"/>
         <source>Warning</source>
-        <translation type="unfinished"></translation>
+        <translation>אזהרה</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="909"/>
@@ -514,8 +514,8 @@
         <location filename="../mainwindow.cpp" line="1793"/>
         <location filename="../mainwindow.cpp" line="1954"/>
         <location filename="../mainwindow.cpp" line="2378"/>
-        <location filename="../mainwindow.cpp" line="2450"/>
-        <location filename="../mainwindow.cpp" line="2477"/>
+        <location filename="../mainwindow.cpp" line="2451"/>
+        <location filename="../mainwindow.cpp" line="2478"/>
         <source>Done</source>
         <translation type="unfinished"></translation>
     </message>
@@ -526,8 +526,8 @@
         <location filename="../mainwindow.cpp" line="1954"/>
         <location filename="../mainwindow.cpp" line="1972"/>
         <location filename="../mainwindow.cpp" line="2378"/>
-        <location filename="../mainwindow.cpp" line="2450"/>
-        <location filename="../mainwindow.cpp" line="2477"/>
+        <location filename="../mainwindow.cpp" line="2451"/>
+        <location filename="../mainwindow.cpp" line="2478"/>
         <source>Processing finished successfully.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -536,8 +536,8 @@
         <location filename="../mainwindow.cpp" line="1786"/>
         <location filename="../mainwindow.cpp" line="1796"/>
         <location filename="../mainwindow.cpp" line="2382"/>
-        <location filename="../mainwindow.cpp" line="2456"/>
-        <location filename="../mainwindow.cpp" line="2483"/>
+        <location filename="../mainwindow.cpp" line="2457"/>
+        <location filename="../mainwindow.cpp" line="2484"/>
         <source>Problem detected while installing, please inspect the console output.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -549,7 +549,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="1807"/>
         <source>Version: </source>
-        <translation type="unfinished"></translation>
+        <translation>גרסה:</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1808"/>
@@ -559,13 +559,13 @@
     <message>
         <location filename="../mainwindow.cpp" line="1810"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>זכויות שמורות MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1811"/>
         <location filename="../mainwindow.cpp" line="1822"/>
         <source>License</source>
-        <translation type="unfinished"></translation>
+        <translation>רשיון</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1812"/>
@@ -750,7 +750,7 @@ OK to go ahead and install it?</source>
     <message>
         <location filename="../main.cpp" line="77"/>
         <source>You must run this program as root.</source>
-        <translation type="unfinished"></translation>
+        <translation>אתה חייב להריץ את התוכנה הזו עם הרשאות root.</translation>
     </message>
 </context>
 </TS>
