@@ -382,8 +382,8 @@
         <location filename="../mainwindow.cpp" line="1959"/>
         <location filename="../mainwindow.cpp" line="1979"/>
         <location filename="../mainwindow.cpp" line="2382"/>
-        <location filename="../mainwindow.cpp" line="2456"/>
-        <location filename="../mainwindow.cpp" line="2483"/>
+        <location filename="../mainwindow.cpp" line="2457"/>
+        <location filename="../mainwindow.cpp" line="2484"/>
         <source>Error</source>
         <translation>Hiba</translation>
     </message>
@@ -514,8 +514,8 @@
         <location filename="../mainwindow.cpp" line="1793"/>
         <location filename="../mainwindow.cpp" line="1954"/>
         <location filename="../mainwindow.cpp" line="2378"/>
-        <location filename="../mainwindow.cpp" line="2450"/>
-        <location filename="../mainwindow.cpp" line="2477"/>
+        <location filename="../mainwindow.cpp" line="2451"/>
+        <location filename="../mainwindow.cpp" line="2478"/>
         <source>Done</source>
         <translation type="unfinished"></translation>
     </message>
@@ -526,8 +526,8 @@
         <location filename="../mainwindow.cpp" line="1954"/>
         <location filename="../mainwindow.cpp" line="1972"/>
         <location filename="../mainwindow.cpp" line="2378"/>
-        <location filename="../mainwindow.cpp" line="2450"/>
-        <location filename="../mainwindow.cpp" line="2477"/>
+        <location filename="../mainwindow.cpp" line="2451"/>
+        <location filename="../mainwindow.cpp" line="2478"/>
         <source>Processing finished successfully.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -536,8 +536,8 @@
         <location filename="../mainwindow.cpp" line="1786"/>
         <location filename="../mainwindow.cpp" line="1796"/>
         <location filename="../mainwindow.cpp" line="2382"/>
-        <location filename="../mainwindow.cpp" line="2456"/>
-        <location filename="../mainwindow.cpp" line="2483"/>
+        <location filename="../mainwindow.cpp" line="2457"/>
+        <location filename="../mainwindow.cpp" line="2484"/>
         <source>Problem detected while installing, please inspect the console output.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -570,12 +570,12 @@
     <message>
         <location filename="../mainwindow.cpp" line="1812"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Változásbejegyzés</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1834"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Bezár</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1889"/>
@@ -651,14 +651,6 @@ OK to go ahead and install it?</source>
         <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Yes</source>
-        <translation type="vanished">Igen</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation type="vanished">Nem</translation>
-    </message>
 </context>
 <context>
     <name>ManageRemotes</name>
@@ -748,12 +740,12 @@ OK to go ahead and install it?</source>
     <message>
         <location filename="../main.cpp" line="58"/>
         <source>Unable to get exclusive lock</source>
-        <translation type="unfinished"></translation>
+        <translation>Egy másik csomagkezelő alkalmazás (vagy a Synaptic, vagy az apt-get) már fut. Kérem zárja be először ezt az alkalmazást!</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="59"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"></translation>
+        <translation>Egy másik csomagkezelő alkalmazás (vagy a Synaptic, vagy az apt-get) már fut. Kérem zárja be először ezt az alkalmazást!</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="77"/>
