@@ -316,7 +316,7 @@
     <message>
         <location filename="../mainwindow.ui" line="1618"/>
         <source>Display help </source>
-        <translation type="unfinished"></translation>
+        <translation>Shfaq ndihmë</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1621"/>
@@ -326,7 +326,7 @@
     <message>
         <location filename="../mainwindow.ui" line="1628"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1644"/>
@@ -382,10 +382,10 @@
         <location filename="../mainwindow.cpp" line="1959"/>
         <location filename="../mainwindow.cpp" line="1979"/>
         <location filename="../mainwindow.cpp" line="2382"/>
-        <location filename="../mainwindow.cpp" line="2456"/>
-        <location filename="../mainwindow.cpp" line="2483"/>
+        <location filename="../mainwindow.cpp" line="2457"/>
+        <location filename="../mainwindow.cpp" line="2484"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Gabim</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="183"/>
@@ -514,8 +514,8 @@
         <location filename="../mainwindow.cpp" line="1793"/>
         <location filename="../mainwindow.cpp" line="1954"/>
         <location filename="../mainwindow.cpp" line="2378"/>
-        <location filename="../mainwindow.cpp" line="2450"/>
-        <location filename="../mainwindow.cpp" line="2477"/>
+        <location filename="../mainwindow.cpp" line="2451"/>
+        <location filename="../mainwindow.cpp" line="2478"/>
         <source>Done</source>
         <translation type="unfinished"></translation>
     </message>
@@ -526,8 +526,8 @@
         <location filename="../mainwindow.cpp" line="1954"/>
         <location filename="../mainwindow.cpp" line="1972"/>
         <location filename="../mainwindow.cpp" line="2378"/>
-        <location filename="../mainwindow.cpp" line="2450"/>
-        <location filename="../mainwindow.cpp" line="2477"/>
+        <location filename="../mainwindow.cpp" line="2451"/>
+        <location filename="../mainwindow.cpp" line="2478"/>
         <source>Processing finished successfully.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -536,8 +536,8 @@
         <location filename="../mainwindow.cpp" line="1786"/>
         <location filename="../mainwindow.cpp" line="1796"/>
         <location filename="../mainwindow.cpp" line="2382"/>
-        <location filename="../mainwindow.cpp" line="2456"/>
-        <location filename="../mainwindow.cpp" line="2483"/>
+        <location filename="../mainwindow.cpp" line="2457"/>
+        <location filename="../mainwindow.cpp" line="2484"/>
         <source>Problem detected while installing, please inspect the console output.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -740,17 +740,17 @@ OK to go ahead and install it?</source>
     <message>
         <location filename="../main.cpp" line="58"/>
         <source>Unable to get exclusive lock</source>
-        <translation type="unfinished"></translation>
+        <translation>E pamundur të bllokohet ekskluzivisht</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="59"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"></translation>
+        <translation>Një tjetër program për menaxhimin e paketave (si Synaptic ose apt-get), tashmë është në punë. Ju lutemi mbyllni atë program së pari</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="77"/>
         <source>You must run this program as root.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ju duhet të lëshoni këtë program si root.</translation>
     </message>
 </context>
 </TS>
